==> kubernetes-model-1.0.40-sources.jar: io/fabric8/kubernetes/api/model/RunAsUserStrategyOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class RunAsUserStrategyOptionsFluentImpl<T extends RunAsUserStrategyOptionsFluent<T>> extends BaseFluent<T> implements RunAsUserStrategyOptionsFluent<T>{

     String type;     Long uid;     Long uidRangeMax;     Long uidRangeMin;     Map<String, Object> additionalProperties = new HashMap();
public RunAsUserStrategyOptionsFluentImpl(){
    
}
public RunAsUserStrategyOptionsFluentImpl( RunAsUserStrategyOptions instance ){
    this.withType(instance.getType()); this.withUid(instance.getUid()); this.withUidRangeMax(instance.getUidRangeMax()); this.withUidRangeMin(instance.getUidRangeMin()); 
}

    public String getType(){
    return this.type;
    }
    public T withType( String type){
    this.type=type; return (T) this;
    }
    public Long getUid(){
    return this.uid;
    }
    public T withUid( Long uid){
    this.uid=uid; return (T) this;
    }
    public Long getUidRangeMax(){
    return this.uidRangeMax;
    }
    public T withUidRangeMax( Long uidRangeMax){
    this.uidRangeMax=uidRangeMax; return (T) this;
    }
    public Long getUidRangeMin(){
    return this.uidRangeMin;
    }
    public T withUidRangeMin( Long uidRangeMin){
    this.uidRangeMin=uidRangeMin; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
RunAsUserStrategyOptionsFluentImpl that = (RunAsUserStrategyOptionsFluentImpl) o;
if (type != null ? !type.equals(that.type) :that.type != null) return false;
if (uid != null ? !uid.equals(that.uid) :that.uid != null) return false;
if (uidRangeMax != null ? !uidRangeMax.equals(that.uidRangeMax) :that.uidRangeMax != null) return false;
if (uidRangeMin != null ? !uidRangeMin.equals(that.uidRangeMin) :that.uidRangeMin != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/RunAsUserStrategyOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class RunAsUserStrategyOptionsFluentImpl<A extends RunAsUserStrategyOptionsFluent<A>> extends BaseFluent<A> implements RunAsUserStrategyOptionsFluent<A>{

     String type;     Long uid;     Long uidRangeMax;     Long uidRangeMin;
public RunAsUserStrategyOptionsFluentImpl(){
    
}
public RunAsUserStrategyOptionsFluentImpl( RunAsUserStrategyOptions instance ){
    this.withType(instance.getType()); this.withUid(instance.getUid()); this.withUidRangeMax(instance.getUidRangeMax()); this.withUidRangeMin(instance.getUidRangeMin()); 
}

    public String getType(){
    return this.type;
    }
    public A withType( String type){
    this.type=type; return (A) this;
    }
    public Long getUid(){
    return this.uid;
    }
    public A withUid( Long uid){
    this.uid=uid; return (A) this;
    }
    public Long getUidRangeMax(){
    return this.uidRangeMax;
    }
    public A withUidRangeMax( Long uidRangeMax){
    this.uidRangeMax=uidRangeMax; return (A) this;
    }
    public Long getUidRangeMin(){
    return this.uidRangeMin;
    }
    public A withUidRangeMin( Long uidRangeMin){
    this.uidRangeMin=uidRangeMin; return (A) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
RunAsUserStrategyOptionsFluentImpl that = (RunAsUserStrategyOptionsFluentImpl) o;
if (type != null ? !type.equals(that.type) :that.type != null) return false;
if (uid != null ? !uid.equals(that.uid) :that.uid != null) return false;
if (uidRangeMax != null ? !uidRangeMax.equals(that.uidRangeMax) :that.uidRangeMax != null) return false;
if (uidRangeMin != null ? !uidRangeMin.equals(that.uidRangeMin) :that.uidRangeMin != null) return false;
return true;

    }



}
